# frozen_string_literal: true

$LOAD_PATH.unshift("#{File.dirname(__FILE__)}/lib")
require_relative '../lib/landline'

class Propogator
  def initialize
    @queue = []
  end

  # Append a client to the queue
  def append(client)
    @queue.append(client)
  end

  # Push data to all clients, releasing all of them at once
  def push(data)
    @queue.each do |client|
      client << data
      client.flush
      client.close
    end
    @queue = []
  end
end

# @!parse include ::Landline::DSL::PathConstructors
# @!parse include ::Landline::DSL::PathMethods

longpoll_queue = Propogator.new

app = Landline::Server.new do
  post "/push_event" do
    longpoll_queue.push(request.body)
    next request.body
  end

  get "/await_event" do
    next "No long polling for you :(" unless request.hijack?

    partial_hijack do |stream|
      longpoll_queue.append(stream)
    end

    next ''
  end

  get "/ping" do
    "pong"
  end
end

run app
