# frozen_string_literal: true

require 'landline'

# Example rack middleware
class TimerMiddleware
  def initialize(app)
    @app = app
  end

  def call(*data)
    puts("Request accepted")
    before = Time.now
    output = @app.call(*data)
    puts("Time elapsed: #{(Time.now - before) * 1000}ms")
    output
  end
end

# Example Landline application as rack middleware
class HelloServer < Landline::App
  setup do
    get "/test2" do
      "Hello world from #{self}!"
    end
    handle do |status, backtrace: nil|
      page = ([Landline::Util::HTTP_STATUS[status]] +
              (backtrace || [""])).join("\n")
      [
        {
          "content-length": page.bytesize,
          "content-type": "text/plain",
          "x-cascade": true
        },
        page
      ]
    end
  end
end

# Example Landline app as rack application
class CrossCallServer < Landline::App
  setup do
    get "/inner_test" do
      "Hello world, through crosscall!"
    end
  end
end

# Example Landline app as rack application
class Server < Landline::App
  use TimerMiddleware
  use HelloServer

  setup do
    crosscall_server = CrossCallServer.new

    get "/test" do
      "Hello from #{self}!"
    end

    # Cross-callable application included as a subpath
    link "/outer", crosscall_server

    # Cross calling an application in a probe context
    get "/crosscall" do
      request.path = "/inner_test"
      call(crosscall_server)
    end
  end
end

run Server.new
