# frozen_string_literal: true

module Landline
  module DSL
    # Probe (and subclasses) DSL construct
    module ProbeConstructors
      # (in Landline::Probe context)
      # Create a new erb template
      # @see Landline::Template#new
      def erb(input, vars = {})
        Landline::Templates::ERB.new(input,
                                     vars,
                                     parent: @origin,
                                     filename: caller_locations[0].path)
      end

      # (in Landline::Probe context)
      # Create a new erb template using Erubi engine
      # @see Landline::Template#new
      # @param freeze [Boolean] whether to use frozen string literal
      # @param capture [Boolean] whether to enable output capturing
      def erubi(input, vars = {}, freeze: true, capture: false)
        Landline::Templates::Erubi.new(input,
                                       vars,
                                       parent: @origin,
                                       freeze: freeze,
                                       capture: capture,
                                       filename: caller_locations[0].path)
      end
    end
  end
end
