# frozen_string_literal: true

require_relative "../probe"

module Landline
  module Handlers
    # Probe that sends files from a location
    class Link < Landline::Probe
      # @param path [Object]
      # @param parent [Landline::Node]
      def initialize(path, application, parent:)
        @application = application
        super(path, parent: parent, filepath: true)
      end

      # Method callback on successful request navigation.
      # Sends request over to another rack app, stripping the part of the path that was not navigated
      # @param request [Landline::Request]
      # @return [Array(Integer, Host{String => Object}, Object)]
      def process(request)
        throw :finish, @application.call(request.env)
      end
    end
  end
end
