# frozen_string_literal: true

require_relative "../probe"

module Landline
  module Handlers
    # Probe that executes callback on a GET
    class GET < Landline::Handlers::Handler
      METHOD = "GET"

      # Method callback on successful request navigation.
      # Runs block supplied with object initialization.
      # Request's #splat and #param are passed to block.
      #
      # Callback's returned should be one of viable responses:
      #
      # - {Landline::Response} object
      # - An array that matches Rack return form
      # - An array that matches old (Rack 2.x) return form
      # - A string (returned as HTML with code 200)
      # - false (bounces the request to next handler)
      # @param request [Landline::Request]
      # @return [Boolean] true if further navigation is possible
      # @raise [UncaughtThrowError] may raise if die() is called.
      def process(request)
        unless request.request_method.casecmp(self.class::METHOD).zero?
          return false
        end

        super(request)
      end
    end

    # Probe that executes callback on a POST
    class POST < GET
      METHOD = "POST"
    end

    # Probe that executes callback on a HEAD
    class HEAD < GET
      METHOD = "HEAD"
    end

    # Probe that executes callback on a PUT
    class PUT < GET
      METHOD = "PUT"
    end

    # Probe that executes callback on a DELETE
    class DELETE < GET
      METHOD = "DELETE"
    end

    # Probe that executes callback on a CONNECT
    class CONNECT < GET
      METHOD = "CONNECT"
    end

    # Probe that executes callback on a OPTIONS
    class OPTIONS < GET
      METHOD = "OPTIONS"
    end

    # Probe that executes callback on a TRACE
    class TRACE < GET
      METHOD = "TRACE"
    end

    # Probe that executes callback on a PATCH
    class PATCH < GET
      METHOD = "PATCH"
    end
  end
end
