# frozen_string_literal: true

require_relative "../probe"
require_relative "../util/mime"

module Landline
  module Handlers
    # Probe that sends files from a location
    class Serve < Landline::Probe
      # @param path [Object]
      # @param parent [Landline::Node]
      def initialize(path, parent:)
        super(path, parent: parent, filepath: true)
      end

      attr_accessor :response

      # Method callback on successful request navigation.
      # Tries to serve files matched by handler
      # @param request [Landline::Request]
      # @return [Boolean, Array] true if file was found
      def process(request)
        path = File.expand_path(request.filepath)
        return unless path.start_with? @properties["path"]

        filepath = path.delete_suffix("/")

        [200,
         {
           "content-type" => Landline::MIME.get_mime_type(filepath)
         },
         File.open(filepath)]
      rescue StandardError
        false
      end
    end
  end
end
