# frozen_string_literal: true

require 'erubi'
require_relative '../template'

module Landline
  module Templates
    # Erubi (ERB) template language adapter
    class Erubi < Landline::Template
      # (see Landline::Template#new)
      def initialize(input,
                     vars = nil,
                     **ext)
        super(input, vars, parent: ext[:parent], filename: ext[:filename])
        varname = "_part_#{SecureRandom.hex(10)}"
        while @binding.local_variable_defined? varname.to_sym
          varname = "_part_#{SecureRandom.hex(10)}"
        end
        properties = {
          bufvar: varname,
          freeze: ext.fetch(:freeze, true)
        }
        capture = ext.fetch(:capture, false)
        engine = capture ? ::Erubi::CaptureEndEngine : ::Erubi::Engine
        @template = engine.new(@template, properties)
      end

      # Run the template.
      def run
        @binding.eval(@template.src, @filename)
      end
    end
  end
end
